==> mastapy-14.0.0rc3-py3-none-any.whl: mastapy/_private/utility/units_and_measurements/measurements/_1787.py <==
"""Volume"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1655
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal import utility

_VOLUME = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Volume"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Volume")
    CastSelf = TypeVar("CastSelf", bound="Volume._Cast_Volume")


__docformat__ = "restructuredtext en"
__all__ = ("Volume",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Volume:
    """Special nested class for casting Volume to subclasses."""

    __parent__: "Volume"

    @property
    def measurement_base(self: "CastSelf") -> "_1655.MeasurementBase":
        return self.__parent__._cast(_1655.MeasurementBase)

    @property
    def volume(self: "CastSelf") -> "Volume":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Volume(_1655.MeasurementBase):
    """Volume

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VOLUME

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Volume":
        """Cast to another type.

        Returns:
            _Cast_Volume
        """
        return _Cast_Volume(self)

==> mastapy-14.0.2-py3-none-any.whl: mastapy/_private/utility/units_and_measurements/measurements/_1787.py <==
"""Voltage"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.utility.units_and_measurements import _1657

_VOLTAGE = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements.Measurements", "Voltage"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Voltage")
    CastSelf = TypeVar("CastSelf", bound="Voltage._Cast_Voltage")


__docformat__ = "restructuredtext en"
__all__ = ("Voltage",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Voltage:
    """Special nested class for casting Voltage to subclasses."""

    __parent__: "Voltage"

    @property
    def measurement_base(self: "CastSelf") -> "_1657.MeasurementBase":
        return self.__parent__._cast(_1657.MeasurementBase)

    @property
    def voltage(self: "CastSelf") -> "Voltage":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Voltage(_1657.MeasurementBase):
    """Voltage

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _VOLTAGE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_Voltage":
        """Cast to another type.

        Returns:
            _Cast_Voltage
        """
        return _Cast_Voltage(self)
